# krules-env

This module is mainly intended for the setup of different environments in the context of a basic image.

KRules is a project in progress and we are working hard on a first widely usable version.

Exhaustive documentation has not yet been released.

If you are interested in getting an idea of the project you can meanwhile take a look at the [overview](https://github.com/airspot-dev/krules-doc/blob/master/OVERVIEW.md) document in which the general concepts are explained.

Do not hesitate to [contact us](mailto:info@airspot.tech) if you are interested in further information.